@@ -4,6 +4,7 @@ from rich.tree import Tree
 from rich.panel import Panel
 from rich import print
 from datetime import datetime, timezone
+from dateutil import parser
 from tickerdax.constants import URL
 
 
@@ -40,6 +41,7 @@ def get_timestamp_range(since, till, timeframe):
     :param datetime since: A start time.
     :param datetime till: A end time.
     :param str timeframe: The string value of the timeframe, i.e. 1m, 1h, 1d, etc.
+    :returns: A list of timestamps.
     :rtype: list[int]
     """
     start = get_unix_time(since, timeframe)
@@ -56,10 +58,29 @@ def get_timestamp_range(since, till, timeframe):
 
 
 def convert_timeframe_to_seconds(timeframe):
+    """
+    Converts a timeframe to its value in seconds.
+
+    :param str timeframe: The string value of the timeframe, i.e. 1m, 1h, 1d, etc.
+    :returns: The value in seconds.
+    :rtype: int
+    """
     seconds_per_unit = {"s": 1, "m": 60, "h": 3600, "d": 86400, "w": 604800}
     return int(timeframe[:-1]) * seconds_per_unit[timeframe[-1]]
 
 
+def iso_string_to_unix_timestamp(time_string, timeframe):
+    """
+    Converts iso formatted time string to unix timestamp.
+
+    :param str time_string: A iso formatted time string.
+    :param str timeframe: The string value of the timeframe, i.e. 1m, 1h, 1d, etc.
+    :returns: A unix timestamp.
+    :rtype: int
+    """
+    return get_unix_time(parser.parse(time_string), timeframe)
+
+
 def show_download_summary(cached_items, downloaded_items, missing_items, missing_ranges):
     tree = Tree(f'- {cached_items} of the requested items were already cached.\n'
                 f'- {downloaded_items} items were downloaded.\n'
